@@ -32,6 +32,7 @@ from cdp_backend.pipeline.ingestion_models import (
     Vote,
 )
 
+from .legistar_content_parsers import all_parsers
 from .scraper_utils import (
     IngestionModelScraper,
     reduced_list,
@@ -39,7 +40,6 @@ from .scraper_utils import (
     str_simplified,
 )
 from .types import ContentURIs, LegistarContentParser, ScraperStaticData
-from .legistar_content_parsers import all_parsers
 
 ###############################################################################
 
@@ -395,6 +395,43 @@ class ContentUriScrapeResult(NamedTuple):
     uris: Optional[List[ContentURIs]] = None
 
 
+def parse_video_page_url(video_page_url: str, client: str) -> List[ContentURIs]:
+    """
+    Return URLs for videos and captions from a Legistar/Granicus-hosted video web page
+
+    Parameters
+    ----------
+    video_page_url: str
+        The URL for the page of the legistar video
+    client: str
+        Which legistar client to target. Ex: "seattle"
+
+    Returns
+    -------
+    uris: Optional[List[ContentURIs]]
+        URIs for video and optional caption
+    """
+    with urlopen(video_page_url) as resp:
+        # now load the page to get the actual video url
+        soup = BeautifulSoup(resp.read(), "html.parser")
+
+        if client in video_page_parser:
+            # we already know which format parser to call
+            uris = video_page_parser[client](client, soup)
+        else:
+            for parser in all_parsers:
+                uris = parser(client, soup)
+                if uris is not None:
+                    # remember so we just call this from here on
+                    video_page_parser[client] = parser
+                    log.debug(f"{parser} for {client}")
+                    break
+            else:
+                uris = None
+
+    return uris
+
+
 def get_legistar_content_uris(client: str, legistar_ev: Dict) -> ContentUriScrapeResult:
     """
     Return URLs for videos and captions from a Legistar/Granicus-hosted video web page
@@ -482,25 +519,8 @@ def get_legistar_content_uris(client: str, legistar_ev: Dict) -> ContentUriScrap
     video_page_url = f"https://{client}.legistar.com/{extract_url[start:end]}"
 
     log.debug(f"{legistar_ev[LEGISTAR_EV_SITE_URL]} -> {video_page_url}")
-
     try:
-        with urlopen(video_page_url) as resp:
-            # now load the page to get the actual video url
-            soup = BeautifulSoup(resp.read(), "html.parser")
-
-            if client in video_page_parser:
-                # we alrady know which format parser to call
-                uris = video_page_parser[client](client, soup)
-            else:
-                for parser in all_parsers:
-                    uris = parser(client, soup)
-                    if uris is not None:
-                        # remember so we just call this from here on
-                        video_page_parser[client] = parser
-                        log.debug(f"{parser} for {client}")
-                        break
-                else:
-                    uris = None
+        uris = parse_video_page_url(video_page_url, client)
     except HTTPError as e:
         log.debug(f"Error opening {video_page_url}:\n{str(e)}")
         return (ContentUriScrapeResult.Status.ResourceAccessError, None)
